@@ -10,9 +10,7 @@ import scipy.sparse as sps
 import scipy.interpolate as sinterp
 import time as tm
 
-import fdyn
-import toolkit
-from utils import *
+import pyfdyn
 
 from paneller import *
 from body import *
@@ -77,7 +75,7 @@ class aircraft: #class to ease certain case studies for full aircraft
             derivs[i, :]=np.array([-self.stabderivative_dict[par]['dCX'], self.stabderivative_dict[par]['dCY'], -self.stabderivative_dict[par]['dCZ'], \
                 -self.stabderivative_dict[par]['dCl'], self.stabderivative_dict[par]['dCm'], -self.stabderivative_dict[par]['dCn']])
             i+=1
-        external_history, alpha_history, beta_history, euler_history, time_history=fdyn.tstep_solve(nstep, dt, self.rho, self.Uinf, self.g, \
+        external_history, alpha_history, beta_history, euler_history, time_history=pyfdyn.tstep_solve(int(nstep), dt, self.rho, self.Uinf, self.g, \
             self.Sref, self.cref, self.bref, perturbations, onboard, self.Inertia, self.m, \
                 coeffs, derivs)
         return external_history, alpha_history, beta_history, euler_history, time_history
@@ -395,12 +393,12 @@ class aircraft: #class to ease certain case studies for full aircraft
             wnglist+=[[]]
             if echo:
                 print('=============================================')
-                print('Design derivatives for incidences in wing %d' % (wngcnt))
+                print('Design derivatives for incidences in wing %d [deg]' % (wngcnt))
             for sect in range(len(wng.wingquads)+1):
-                dFs, dMs=wng.calc_design_dFM(section=sect, Uinf=self.Uinf, rho=self.rho, CG=self.CG)
+                dFs, dMs=wng.calc_design_dFM(section=sect, Uinf=self.Uinf, M=self.M, gamma=self.gamma, rho=self.rho, CG=self.CG)
                 #transform to derivatives in respect to degrees
-                dFs*=np.pi/180.0
-                dMs*=np.pi/180.0
+                '''dFs*=np.pi/180.0
+                dMs*=np.pi/180.0'''
                 dFs/=self.Sref*self.rho*self.Uinf**2/2
                 dMs[0]/=self.Sref*self.bref*self.rho*self.Uinf**2/2
                 dMs[1]/=self.Sref*self.cref*self.rho*self.Uinf**2/2
