@@ -11,7 +11,7 @@ import time as tm
 import multiprocessing as mp
 import os
 
-import toolkit
+import pytoolkit
 from utils import *
 
 class Panel: #Panel data type
@@ -26,7 +26,7 @@ class Panel: #Panel data type
 def subprocess_genaicm(queue1, queue2): #generic function to unpack AICM calc order from multiprocessing 
     #queue and deliver it to calculating function in toolkit
     order=queue1.get()
-    AICM=toolkit.aicm_lines_gen(order[2], order[3])
+    AICM=pytoolkit.aicm_lines_gen(order[2], order[3])
     queue2.put((order[0], order[1], AICM))
 
 class WakeLine: #class encompassing info about a wake line. Made so as to compute deformation with wake rollup
@@ -420,7 +420,7 @@ class Solid:
         self.aicm3=np.zeros((3, self.npanels, self.npanels))
         for i in range(3):
             self.aicm3[i, :, :]=self.aicm3_line[i, :, :]@self.panline_matrix
-        self.aicm=toolkit.aicm_norm_conv(self.aicm3, nvectmat)
+        self.aicm=pytoolkit.aicm_norm_conv(self.aicm3, nvectmat)
     def gen_farfield(self, Uinf, a=0.0, b=0.0, p=0.0, q=0.0, r=0.0): #generate generic local freestream velocity dependant on parameters
         newvec=np.zeros((self.npanels, 3))
         for i in range(self.npanels):
@@ -518,10 +518,10 @@ class Solid:
             tvel=tm.time()
             self.wake_rollup()
             trol=tm.time()
-            self.aicm3_line[:, :, wakelininds]=toolkit.aicm_lines_recalc(wakelininds+1, self.lines, colmat)
+            self.aicm3_line[:, :, wakelininds]=pytoolkit.aicm_lines_recalc(wakelininds, self.lines, colmat)
             for j in range(3):
                 self.aicm3[j, :, :]=self.aicm3_line[j, :, :]@self.panline_matrix
-            self.aicm=toolkit.aicm_norm_conv(self.aicm3, nvectmat)
+            self.aicm=pytoolkit.aicm_norm_conv(self.aicm3, nvectmat)
             if damper!=0.0:
                 self.iaicm=slg.inv(self.aicm.T@self.aicm+damper*np.eye(self.npanels, self.npanels))@self.aicm.T
             else:
@@ -534,15 +534,19 @@ class Solid:
         for i in range(3):
             self.delphi[:, i]=self.aicm3[i, :, :]@self.solution #compute local velocity due to disturbance field
         self.gen_selfinf()
-    def calcpress(self, Uinf=1.0):
-        for i in range(self.npanels):
-            self.Cps[i]=(Uinf**2-(self.delphi[i, :]+self.vbar[i, :])@(self.delphi[i, :]+self.vbar[i, :]))/Uinf**2
+    def calcpress(self, Uinf=1.0, gamma=1.4, M=0.0):
+        if M==0.0:
+            for i in range(self.npanels):
+                self.Cps[i]=(Uinf**2-(self.delphi[i, :]+self.vbar[i, :])@(self.delphi[i, :]+self.vbar[i, :]))/Uinf**2
+        else:
+            for i in range(self.npanels):
+                incomp=(Uinf**2-(self.delphi[i, :]+self.vbar[i, :])@(self.delphi[i, :]+self.vbar[i, :]))/Uinf**2 #incompressible value
+                self.Cps[i]=2*((1.0+(gamma-1)*M**2*incomp/2)**(gamma/(gamma-1))-1)/(M**2*gamma)
     def calcforces(self): #compute force correspondent to unitary dynamic pressure on each panel
         self.forces=[-self.panels[i].S*self.panels[i].nvector*self.Cps[i]+self.panels[i].S*self.Cfs[i]*\
             (self.vbar[i, :]+self.delphi[i, :])/lg.norm(self.vbar[i, :]+self.delphi[i, :]) for i in range(self.npanels)]
         self.moments=[np.cross(self.panels[i].colpoint, self.forces[i]) for i in range(self.npanels)]
-    def calc_derivative(self, Uinf, a=0.0, b=0.0, p=0.0, q=0.0, r=0.0, par='a'): #calculate local Cp derivative by freestream factor
-        dvdksi=self.gen_farfield_derivative(Uinf, a=0.0, b=0.0, p=0.0, q=0.0, r=0.0, par=par)
+    def calc_derivative_dv(self, Uinf, dvdksi, M=0.0, gamma=1.4): #calculate local Cp derivative by freestream derivative
         dndksi=np.array([self.panels[i].nvector@dvdksi[i, :] for i in range(self.npanels)])
         dGammadksi=-self.iaicm@dndksi
         dGamma_linedksi=self.panline_matrix@dGammadksi
@@ -550,11 +554,28 @@ class Solid:
         dvdksi[:, 1]+=self.aicm3[1, :, :]@dGammadksi+self.selfinf_mat_y@dGamma_linedksi
         dvdksi[:, 2]+=self.aicm3[2, :, :]@dGammadksi+self.selfinf_mat_z@dGamma_linedksi
         dCps=np.array([-(2*(self.vbar[i, :]+self.delphi[i, :])@dvdksi[i, :])/Uinf**2 for i in range(self.npanels)])
+        if M!=0.0:
+            for i in range(self.npanels):
+                incomp=(Uinf**2-(self.delphi[i, :]+self.vbar[i, :])@(self.delphi[i, :]+self.vbar[i, :]))/Uinf**2 #incompressible value
+                dCps[i]=2*((1+(gamma-1)*M**2*incomp/2)**(1.0/(gamma-1.0)))*dCps[i]/(M**2*(gamma-1.0))
+        return dCps
+    def calc_derivative_dn(self, Uinf, dndksi, M=0.0, gamma=1.4): #calculate local Cp derivative by normal velocity derivative
+        dGammadksi=-self.iaicm@dndksi
+        dGamma_linedksi=self.panline_matrix@dGammadksi
+        dvdksi=np.zeros((len(dndksi), 3))
+        dvdksi[:, 0]=self.aicm3[0, :, :]@dGammadksi+self.selfinf_mat_x@dGamma_linedksi
+        dvdksi[:, 1]=self.aicm3[1, :, :]@dGammadksi+self.selfinf_mat_y@dGamma_linedksi
+        dvdksi[:, 2]=self.aicm3[2, :, :]@dGammadksi+self.selfinf_mat_z@dGamma_linedksi
+        dCps=np.array([-(2*(self.vbar[i, :]+self.delphi[i, :])@dvdksi[i, :])/Uinf**2 for i in range(self.npanels)])
+        if M!=0.0:
+            for i in range(self.npanels):
+                incomp=(Uinf**2-(self.delphi[i, :]+self.vbar[i, :])@(self.delphi[i, :]+self.vbar[i, :]))/Uinf**2 #incompressible value
+                dCps[i]=2*((1+(gamma-1)*M**2*incomp/2)**(1.0/(gamma-1.0)))*dCps[i]/(M**2*(gamma-1.0))
         return dCps
     def add_wakevels(self, tolerance=1e-5): #calculate velocities at wake panel control points and add to local velocity variables
         for strip in self.wakestrips:
             for p in strip:
-                p.v+=toolkit.get_field_influence(self.lines, self.solution_line, p.center, tolerance=tolerance)
+                p.v+=pytoolkit.get_field_influence(self.lines, self.solution_line, p.center, tolerance=tolerance)
     def wake_rollup(self): #calculate velocity at nodes located at wake line midpoints and update the lines
         for strip in self.wakestrips:
             for p in strip:
@@ -655,10 +676,6 @@ class Solid:
         for i in self.problematic:
             ax.plot3D(self.lines[i, 0, :], self.lines[i, 1, :], self.lines[i, 2, :], 'red')
         if self.solavailable and velfield:
-            '''ax.quiver([p.colpoint[0] for p in self.panels], [p.colpoint[1] for p in self.panels], \
-                [p.colpoint[2] for p in self.panels], [p.nvector[0]*0.005 for p in self.panels], \
-                    [p.nvector[1]*0.005 for p in self.panels], \
-                        [p.nvector[2]*0.005 for p in self.panels])'''
             ax.quiver([p.colpoint[0] for p in self.panels], [p.colpoint[1] for p in self.panels], \
                 [p.colpoint[2] for p in self.panels], [(self.vbar[i, 0]+self.delphi[i, 0])*factor for i in range(self.npanels)], \
                     [(self.vbar[i, 1]+self.delphi[i, 1])*factor for i in range(self.npanels)], \
@@ -697,7 +714,7 @@ class Solid:
         plt.xlabel('x')
         plt.ylabel('y')
         plt.show()
-    def eulersolve(self, target=np.array([]), Uinf=1.0, beta=1.0, a=0.0, b=0.0, p=0.0, q=0.0, r=0.0, damper=0.0, echo=True, \
+    def eulersolve(self, target=np.array([]), Uinf=1.0, M=0.0, gamma=1.4, beta=1.0, a=0.0, b=0.0, p=0.0, q=0.0, r=0.0, damper=0.0, echo=True, \
         wakeiter=0, tolerance=1e-5):
         if echo:
             print('========Euler solution=======')
@@ -716,7 +733,7 @@ class Solid:
         t=tm.time()
         self.PG_remove(beta, a, b)
         self.solve(damper=damper, wakeiter=wakeiter, Uinf=Uinf, a=a, b=b, p=p, q=q, r=r, tolerance=tolerance, echo=echo)
-        self.calcpress(Uinf=Uinf)
+        self.calcpress(Uinf=Uinf, M=M, gamma=gamma)
         self.calcforces()
         if echo:
             print('Solution and post-processing: '+str(tm.time()-t)+' s')
